@@ -3,12 +3,14 @@
 {
     'name': 'Account',
     'name_bg_BG': 'Фактури',
+    'name_ca_ES': 'Comptabilitat',
     'name_de_DE': 'Buchhaltung',
+    'name_es_AR': 'Contabilidad',
     'name_es_CO': 'Contabilidad',
     'name_es_ES': 'Contabilidad',
     'name_fr_FR': 'Comptabilité',
     'name_nl_NL': 'Boekhouden',
-    'version': '2.2.7',
+    'version': '2.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -43,6 +45,22 @@ And with reports:
     - Баланс на външен партньор
     - Хронологичен баланс
     - Общ дневник
+''',
+    'description_ca_ES': '''Mòdul financer i comptable amb:
+    - Comptabilitat general
+    - Gestió d'exercicis fiscals
+    - Administració d'impostos
+    - Llibres diaris
+    - Conciliació
+
+I amb els informes:
+    - Llibre major
+    - Balanç de sumes i saldos
+    - Balanç de situació
+    - Balanç pèrdues i guanys
+    - Balanç de tercers
+    - Saldo vençut
+    - Diari
 ''',
     'description_de_DE': '''Buchhaltungsmodul mit:
     - Allgemeiner Buchhaltung
@@ -59,6 +77,22 @@ Zugehörige Berichte:
     - Offene Posten
     - Fälligkeitsliste
     - Allgemeines Journal
+''',
+    'description_es_AR': '''Módulo financiero y de contabilidad con:
+    - Contabilidad General
+    - Gestión de ejercicios fiscales
+    - Gestión de impuestos
+    - Libros diarios
+    - Conciliación
+
+Y con los informes:
+    - Libro mayor
+    - Balance de sumas y saldos
+    - Balance general
+    - Estado de pérdidas y ganancias
+    - Balance de una Entidad
+    - Saldo Vencido
+    - Libro diario
 ''',
     'description_es_CO': '''El módulo Financiero y de Contabilidad cuenta con:
     - Contabilidad General
@@ -76,8 +110,8 @@ Y con los reportes:
     - Saldos Vencidos
     - Diario general
 ''',
-    'description_es_ES': '''Módulo financiero y de contabilidad con:
-    - Contabilidad General
+    'description_es_ES': '''Módulo financiero y contable con:
+    - Contabilidad general
     - Gestión de ejercicios fiscales
     - Gestión de impuestos
     - Libros diarios
@@ -86,10 +120,10 @@ Y con los reportes:
 Y con los informes:
     - Libro mayor
     - Balance de sumas y saldos
-    - Balance general
-    - Estado de pérdidas y ganancias
-    - Balance de un Tercero
-    - Saldo Vencido
+    - Balance de situación
+    - Balance pérdidas y ganancias
+    - Balance de terceros
+    - Saldo vencido
     - Libro diario
 ''',
     'description_fr_FR': '''Module financier et comptable avec:
@@ -133,6 +167,7 @@ Met bijbehorende rapporten:
     ],
     'xml': [
         'account.xml',
+        'configuration.xml',
         'fiscalyear.xml',
         'period.xml',
         'journal.xml',
@@ -142,8 +177,10 @@ Met bijbehorende rapporten:
     ],
     'translation': [
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/cs_CZ.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
